IDeliveryRepository class abstract

Constructors

IDeliveryRepository({required ILocationRepository locationRepository, required APIRepository apiRepository, required IUserRepository userRepository, int orderCount = 0})

Properties

apiRepository APIRepository
final
hashCode int
The hash code for this object.
no setterinherited
locationRepository ILocationRepository
final
orderCount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userRepository IUserRepository
final

Methods

acceptOrder() Future<void>
clear() → void
emitLocation() → void
getOrderCount() Future<int>
init() Future<void>
markAsDelivered() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited