IUserRepository class abstract

Implementers

Constructors

IUserRepository({required APIRepository apiRepository, required StorageRepository storageRepository})

Properties

apiRepository APIRepository
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageRepository StorageRepository
final
user Map?
getter/setter pair
userDetails Map?
no setter

Methods

clear() → void
getUserFromAPI() Future<Map?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUser(Map user) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited