ImagePickerUtil class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
Build bottom popup modal for source selection
-
buildImage(Map imageMap, {required MiCubit<MiState>? cubit, required Map? widgetArgs, required Color? resolveColor(String?)})
→ Widget
-
Build image preview widget based on image map
-
buildMaxSizeLabel({required double? maxUploadSize, required Color? resolveColor(String?)})
→ Widget
-
Build max size label widget
-
getPreviewColorByExtension(String extension)
→ Color
-
Get preview color based on file extension
-
pickImage({required BuildContext context, required ImageSource source, required bool allowMultiple, required List<String>? allowedExtensions, required double? maxUploadSize, required Future<void> processImagePickerResult({required BuildContext context, required dynamic imagePickerResult})})
→ Future<void>
-
Pick images from camera or gallery
-
updateImagePath({required dynamic imageMaps, required bool allowMultiple, required MiCubit<MiState>? cubit, required String imagePathKey, required Map? widgetArgs, bool includeNotUploaded = false})
→ void
-
Update image path in cubit