MiState class

Implementers

Constructors

MiState({required Map data, required Map uiConfig, required Map pageArgs, required Widget? ui, required PageState pageState, required String stateMessage, required int updates})
const
MiState.init()
factory

Properties

data Map
final
hashCode int
The hash code for this object.
no setterinherited
pageArgs Map
final
pageState PageState
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateMessage String
final
stringify bool
If set to true, the toString method will be overridden to output this instance's props.
no setter
ui Widget?
final
uiConfig Map
final
updates int
final

Methods

copyWith({Map? data, Map? uiConfig, Map? pageArgs, Widget? ui, PageState? pageState, String? stateMessage, int? updates}) MiState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited